<?php

/* Enqueue styles and scripts for our theme options page. */
function adventurebound_admin_enqueue_scripts( $hook_suffix ) {
	wp_enqueue_style( 'adventurebound-theme-options', get_template_directory_uri() . '/theme-options.css', false, '2011-04-28' );
	wp_enqueue_script( 'adventurebound-theme-options', get_template_directory_uri() . '/theme-options.js', array( 'farbtastic' ), '2011-06-10' );
	wp_enqueue_style( 'farbtastic' ); }

add_action( 'admin_print_styles-appearance_page_theme_options', 'adventurebound_admin_enqueue_scripts' );

/*  Register the form setting for our adventurebound_options array. */
function adventurebound_theme_options_init() {

	// If we have no options in the database, let's add them now.
	if ( false === adventurebound_get_theme_options() )
		add_option( 'adventurebound_theme_options', adventurebound_get_default_theme_options() );
		
	register_setting(
		'adventurebound_options', 				// Options group, see settings_fields() call in adventurebound_theme_options_render_page()
		'adventurebound_theme_options',			// Database option, see adventurebound_get_theme_options()
		'adventurebound_theme_options_validate'	// The sanitization callback, see adventurebound_theme_options_validate()
	);

	// Register our settings field group
	add_settings_section(
		'general',			// Unique identifier for the settings section
		'',					// Section title (we don't want one)
		'__return_false',	// Section callback (we don't want anything)
		'theme_options'		// Menu slug, used to uniquely identify the page; see adventurebound_theme_options_add_page()
	);
	
	add_settings_field( 'thank_you', __( '<b>Thank You</b>', 'adventurebound' ), 'adventurebound_thank_you', 'theme_options', 'general' );
	add_settings_field( 'premium_options', __( '<b>Activate Adenture</br>Bound Features</b>', 'adventurebound' ), 'adventurebound_active_premium_options', 'theme_options', 'general' );
	add_settings_field( 'active', __( '', 'adventurebound' ), 'adventurebound_is_active', 'theme_options', 'general' );
	add_settings_field( 'link_color', __( '<b>Link Color</b></br>(Only Avaliable</br> with Purchase)', 'adventurebound' ), 'adventurebound_settings_field_link_color', 'theme_options', 'general' );
	add_settings_field( 'date_option', __( '<b>Blog Dates</b></br>(Only Avaliable</br> with Purchase)', 'adventurebound' ), 'adventurebound_settings_field_layout', 'theme_options', 'general' );
	add_settings_field( 'featured_image', __( '<b>Featured Image</b></br>(Only Avaliable</br> with Purchase)', 'adventurebound' ), 'adventurebound_settings_featured_image', 'theme_options', 'general' );
	add_settings_field( 'hide_tag', __( '<b>Hides Tags</b></br>(Only Avaliable</br> with Purchase)', 'adventurebound' ), 'adventurebound_settings_hide_tag', 'theme_options', 'general' ); }

add_action( 'admin_init', 'adventurebound_theme_options_init' );

function adventurebound_option_page_capability( $capability ) {
	return 'edit_theme_options'; }

add_filter( 'option_page_capability_adventurebound_options', 'adventurebound_option_page_capability' );

/* Adds in the options help menu (I know it needs work) */ 
function adventurebound_theme_options_add_page() {
	$theme_page = add_theme_page(
		__( 'Theme Options', 'adventurebound' ),	// Name of page
		__( 'Theme Options', 'adventurebound' ),	// Label in menu
		'edit_theme_options',						// Capability required
		'theme_options',							// Menu slug, used to uniquely identify the page
		'adventurebound_theme_options_render_page'	// Function that renders the options page
	);
	
	if ( ! $theme_page )
		return;
		
	add_action( "load-$theme_page", 'adventurebound_theme_options_help' ); }
	
add_action( 'admin_menu', 'adventurebound_theme_options_add_page' );

function adventurebound_theme_options_help() {
	$help = '<p>' . __( 'The Adventure Bound Basic Bound Theme by Eric Schwarz provides customization options that are grouped together on the Theme Options screen. If you change themes, options may change or disappear, as they are theme-specific. Your current theme, Adventure Bound Basic, does not provides the following Theme Options, they are only available with the with the premium version Adventure Bound:', 'adventurebound' ) . '</p>' .
		'<ol>' .
		'<li>' . __( '<strong>Website Color</strong>: You can choose from a bunch of different images to customize the look and feel for your entire site.', 'adventurebound' ) . '</li>' .
		'<li>' . __( '<strong>Hide Date</strong>: You can choose the opption of not display the date on the home.', 'adventurebound' ) . '</li>' .
		'</ol>' .
		'<p>' . __( 'Remember to click "Save Changes" to save any changes you have made to the theme options.', 'adventurebound' ) . '</p>' .
		'<p><strong>' . __( 'For more information:', 'adventurebound' ) . '</strong></p>' .
		'<p>' . __( '<a href="http://schwarttzy.com/web-design/adventure-bound/" target="_blank">Adventure Bound Basic Home Page</a>', 'adventurebound' ) . '</p>' .
		'<p>' . __( '<a href="http://schwarttzy.com/shop/adventure-bound/" target="_blank">The Premium Adventure Bound Home Page</a>', 'adventurebound' ) . '</p>' .
		'<p>' . __( '<a href="http://schwarttzy.com/contact-me/" target="_blank">Contact Eric Schwarz</a>', 'adventurebound' ) . '</p>';

	$sidebar = '<p><strong>' . __( 'For more information:', 'adventurebound' ) . '</strong></p>' .
		'<p>' . __( '<a href="http://codex.wordpress.org/Appearance_Theme_Options_Screen" target="_blank">Documentation on Theme Options</a>', 'adventurebound' ) . '</p>' .
		'<p>' . __( '<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>', 'adventurebound' ) . '</p>';

	$screen = get_current_screen();

	if ( method_exists( $screen, 'add_help_tab' ) ) {
		$screen->add_help_tab( array(
			'title' => __( 'Overview', 'adventurebound' ),
			'id' => 'theme-options-help',
			'content' => $help, )
		);

		$screen->set_help_sidebar( $sidebar ); }
	else { add_contextual_help( $screen, $help . $sidebar ); } }

/* Returns an arry for the default color, I have plans for this down the road to much more. */
function adventurebound_link_color() {
	$link_color_options = array(
		'red' => array(
			'value' => 'red',
			'default_link_color' => '#d71015',
		),
	);

return apply_filters( 'adventurebound_link_color', $link_color_options ); }

/* Returns an array of display options registered for Adventure Bound. */
function adventurebound_layouts() {
	$layout_options = array(
		'dates' => array(
			'value' => 'dates',
			'label' => __( 'Dates', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/date.jpg',
		),
		'no-dates' => array(
			'value' => 'no-dates',
			'label' => __( 'No-Dates', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/no-date.jpg',
		),
		'no-hover' => array(
			'value' => 'no-hover',
			'label' => __( 'Information Allways Displayed', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/no-hover.jpg',
		),
	);

	return apply_filters( 'adventurebound_layouts', $layout_options ); }

/* Returns an array of Featured Image options registered for Adventure Bound. */
function adventurebound_featured_image() {
	$feature_image_options = array(
		'featured' => array(
			'value' => 'featured',
			'label' => __( 'Featured Images', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/featured.jpg',
		),
		'no-featured' => array(
			'value' => 'no-featured',
			'label' => __( 'No Featured Images', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/no-featured.jpg',
		),
		'postonly' => array(
			'value' => 'postonly',
			'label' => __( 'Only on Posts', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/featured.jpg',
		),
		'pageonly' => array(
			'value' => 'pageonly',
			'label' => __( 'Only on Pages', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/featured.jpg',
		),
	);

	return apply_filters( 'adventurebound_featured_image', $feature_image_options ); }
	
/* Returns an array for hiding tags and categories Adventure Bound. */
function adventurebound_hide_tag() {
	$feature_image_options = array(
		'tags' => array(
			'value' => 'tags',
			'label' => __( 'Tags are displayed.', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/tags.jpg',
		),
		'no-tags' => array(
			'value' => 'no-tags',
			'label' => __( 'Tags and Categories Will Not Display', 'adventurebound' ),
			'thumbnail' => get_template_directory_uri() . '/images/no-tags.jpg',
		),
	);

	return apply_filters( 'adventurebound_hide_tag', $feature_image_options ); }

/* Setup the default Theme Options in Adventure Bound */
function adventurebound_get_default_theme_options() {

	$default_theme_options = array(
		'link_color' => 'red',
		'premium_options' => 'Paste Transaction Code',
		'active' => 'deactive',
		'link_color'   => adventurebound_get_default_link_color( 'red' ),
		'theme_layout' => 'content-sidebar',
		'featured_image' => 'featured',
		'hide_tag' => 'tags', );

	if ( is_rtl() )
 		$default_theme_options['theme_layout'] = 'red';

	return apply_filters( 'adventurebound_default_theme_options', $default_theme_options ); }

/* Returns the default link color for Adventure Bound, based on color scheme. */
function adventurebound_get_default_link_color( $link_color = null ) {

	if ( null === $link_color ) {
		$options = adventurebound_get_theme_options();
		$link_color = $options['link_color']; }

	$link_colors = adventurebound_link_color();
	
	if ( ! isset( $link_colors[ $link_color ] ) )
		return false;
		
	return $link_colors[ $link_color ]['default_link_color']; }

/* Returns the options array for Adventure Bound. */
function adventurebound_get_theme_options() {
	return get_option( 'adventurebound_theme_options', adventurebound_get_default_theme_options() ); }
	
/* Renders the Thank You setting field. */
function adventurebound_thank_you() { ?>
    <h2><b>Thank You</b> for supporting my WordPress Theme "Adventure Bound Basic."</h2>
    <p>I encourage you to regularly check for updates because I spend a lot of time improving and fixing the code so that it just simply keeps working better. WordPress will alert you to updates but you can find the blead-edge downloads <a href="http://schwarttzy.com/web-design/adventure-bound/" target="_blank">Here</a>.</p>
    
    <p>I'm trying to make a career out of building themes for WordPress just like this one. Which is why I offer the following premium features to further customize this theme for your enjoyment. If you would like to have the additional features or just want to support my work, you can do so <a href="http://schwarttzy.com/shop/adventure-bound/" target="_blank">here</a>.</p>
    <ol>
    <li>Change Website Color Base (Anything that is that particular Red)</li>
    <li>Customize the Menu at the Bottom</li>
    <li>Additional Search Engine Optimization</li>
    <li>Change the Secondary Menu's Image (Coming Soon)</li>
    <li>The inclution of the PhotoShop Images Files in the download.</li>
    <li>Code for Website Favorite Icons included.</li>
    <li>Minor Custom Modifications to the Theme</li>
    <li>My Support with any questions or problems you may have.</li>
    <li>AND MORE FEATURES TO COME SOON, AT NO ADDTIONAL CHARGE!</li>
    </ol>
    <p>If you have any questions, comments, problems, or suggestions please feel free to <a href="http://schwarttzy.com/contact-me/" target="_blank">Contact Me Here.</a></p>
    <p>Thank you for using my Theme,</p>
    <a href="http://schwarttzy.com/about-2/" target="_blank"><P>Eric J. Schwarz</P></a><?php }

function adventurebound_active_premium_options() {
	$options = adventurebound_get_theme_options(); ?>
	<input type="text" name="adventurebound_theme_options[premium_options]" id="premium-options" value="<?php echo $options['premium_options']; ?>" /> <b><?php echo strtoupper ($options['active']);?></b><?php if ($options['active'] != 'active'){ ?></br><?php echo ' Paste the Transaction Code from the in the email you receive from Schwarttzy.com in the box above and click "Save" at the bottom to enable the premium features.';?> <a href="http://Schwarttzy.com/transaction.png" target="_blank">Click Here to see a sample.</a> <?php } }

function adventurebound_is_active() {
	$options = adventurebound_get_theme_options();}

/* Renders the Color Scheme setting field. */
function adventurebound_settings_field_color_scheme() {
	$options = adventurebound_get_theme_options();
	foreach ( adventurebound_link_color() as $scheme ) { ?>
    
	<div class="layout image-radio-option color-scheme">
	<label class="description">
		<input type="radio" name="adventurebound_theme_options[color_scheme]" value="<?php echo esc_attr( $scheme['value'] ); ?>" <?php checked( $options['link_color'], $scheme['value'] ); ?> />
        <input type="hidden" id="default-color-<?php echo esc_attr( $scheme['value'] ); ?>" value="<?php echo esc_attr( $scheme['default_link_color'] ); ?>" />
        <span><img src="<?php echo esc_url( $scheme['thumbnail'] ); ?>" width="136" height="122" alt="" /><?php echo $scheme['label']; ?></span>
	</label>
	</div>
	<?php } }

/* Renders the Link Color setting field. */
function adventurebound_settings_field_link_color() {
	$options = adventurebound_get_theme_options(); ?>
	<input type="text" name="adventurebound_theme_options[link_color]" id="link-color" value="<?php echo esc_attr( $options['link_color'] ); ?>" />
	<a href="#" class="pickcolor hide-if-no-js" id="link-color-example"></a>
	<input type="button" class="pickcolor button hide-if-no-js" value="<?php esc_attr_e( 'Select a Color', 'adventurebound' ); ?>" />
	<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div>
	<br/>
	<span><?php printf( __( 'Default color: %s', 'adventurebound' ), '<span id="default-color">' . adventurebound_get_default_link_color( $options['link_color'] ) . '</span>' ); ?></span>
	<?php }

/* Renders the Layout setting field. */
function adventurebound_settings_field_layout() {
	$options = adventurebound_get_theme_options();
	foreach ( adventurebound_layouts() as $layout ) { ?>
    	<div class="layout image-radio-option theme-layout">
        <label class="description">
        	<input type="radio" name="adventurebound_theme_options[theme_layout]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['theme_layout'], $layout['value'] ); ?> />
            <span><img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" /><?php echo $layout['label']; ?></span>
		</label>
        </div>
		<?php } }

/* Renders the Featured Image Options setting field. */
function adventurebound_settings_featured_image() {
	$options = adventurebound_get_theme_options();
	foreach ( adventurebound_featured_image() as $layout ) { ?>
    	<div class="layout image-radio-option theme-layout">
        <label class="description">
        	<input type="radio" name="adventurebound_theme_options[featured_image]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['featured_image'], $layout['value'] ); ?> />
            <span><img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" /><?php echo $layout['label']; ?></span>
		</label>
        </div>
		<?php } }
		
/* Renders the Featured Image Options setting field. */
function adventurebound_settings_hide_tag() {
	$options = adventurebound_get_theme_options();
	foreach ( adventurebound_hide_tag() as $layout ) { ?>
    	<div class="layout image-radio-option theme-layout">
        <label class="description">
        	<input type="radio" name="adventurebound_theme_options[hide_tag]" value="<?php echo esc_attr( $layout['value'] ); ?>" <?php checked( $options['hide_tag'], $layout['value'] ); ?> />
            <span><img src="<?php echo esc_url( $layout['thumbnail'] ); ?>" width="136" height="122" alt="" /><?php echo $layout['label']; ?></span>
		</label>
        </div>
		<?php } }

/* Returns the options array for Adventure Bound. */
function adventurebound_theme_options_render_page() { ?>
	<div class="wrap">
		<?php screen_icon(); ?>
        <h2><?php printf( __( '%s Theme Options', 'adventurebound' ), get_current_theme() ); ?></h2>
        <?php settings_errors(); ?>
        
        <form method="post" action="options.php">
        	<?php
				settings_fields( 'adventurebound_options' );
				do_settings_sections( 'theme_options' );
				submit_button();
			?>
		</form>
	</div>
	<?php }

/* Sanitize and validate form input. Accepts an array, return a sanitized array.  */
function adventurebound_theme_options_validate( $input ) {
	$output = $defaults = adventurebound_get_default_theme_options();

	// Color scheme must be in our array of color scheme options
	if ( isset( $input['link_color'] ) && array_key_exists( $input['link_color'], adventurebound_link_color() ) )
		$output['link_color'] = $input['link_color'];

	$options = adventurebound_get_theme_options();
	// Sanitize $input['premium_options']
	$input['premium_options'] = strtoupper ( ltrim( $input['premium_options'] ) );
	
	// Determine if we need to poll the activation code server
	if ( $input['premium_options'] != $options['premium_options'] && 'active' != $options['active'] ) {
		// Build premium options activation server URL
		$actives = 'http://schwarttzy.com/varifys.php?actives=' . $input['premium_options'];
		// Poll the activation server
		$homepage = wp_remote_request( $actives );
		// Set $output['active'] accordingly
		$output['active'] = ( 'active' == $homepage[body] ? 'active' : 'deactive' );
		$output['premium_options'] = $input['premium_options']; }
	elseif ( $input['premium_options'] == $options['premium_options'] && 'active' == $options['active'] ) {
		$output['active'] = 'active';
		$output['premium_options'] = $input['premium_options']; }

	// Our defaults for the link color may have changed, based on the color scheme.
	$output['link_color'] = $defaults['link_color'] = adventurebound_get_default_link_color( $output['link_color'] );
	
	// Link color must be 3 or 6 hexadecimal characters
	if ( isset( $input['link_color'] ) && preg_match( '/^#?([a-f0-9]{3}){1,2}$/i', $input['link_color'] ) )
		$output['link_color'] = '#' . strtolower( ltrim( $input['link_color'], '#' ) );

	// Theme layout must be in our array of theme layout options
	if ( isset( $input['theme_layout'] ) && array_key_exists( $input['theme_layout'], adventurebound_layouts() ) )
		$output['theme_layout'] = $input['theme_layout'];

	// Theme layout must be in our array of theme layout options
	if ( isset( $input['featured_image'] ) && array_key_exists( $input['featured_image'], adventurebound_featured_image() ) )
		$output['featured_image'] = $input['featured_image'];

	// Theme layout must be in our array of theme layout options
	if ( isset( $input['hide_tag'] ) && array_key_exists( $input['hide_tag'], adventurebound_hide_tag() ) )
		$output['hide_tag'] = $input['hide_tag'];

	return apply_filters( 'adventurebound_theme_options_validate', $output, $input, $defaults ); }

/* Enqueue the styles for the current color scheme. */
function adventurebound_enqueue_color_scheme() {
	$options = adventurebound_get_theme_options();
	$link_color = $options['link_color'];
	
	if ( 'no-dates' == $link_color )
		wp_enqueue_style( 'no-dates', get_template_directory_uri() . '/no-dates.css', array(), null );

	do_action( 'adventurebound_enqueue_color_scheme', $link_color ); }

add_action( 'wp_enqueue_scripts', 'adventurebound_enqueue_color_scheme' );

/* Adds Adventure Bound layout classes to the array of body classes. */
function adventurebound_layout_classes( $existing_classes ) {
	$options = adventurebound_get_theme_options();
	$current_layout = $options['theme_layout'];
	if ( in_array( $current_layout, array( 'dates', 'no-dates', 'no-hover' ) ) )
	
	;// Do nothing for right now - Eric Schwarz
	else
		$classes = array( 'error' );

	if ( 'dates' == $current_layout )
		$classes[] = 'dates';

	elseif ( 'no-dates' == $current_layout )
		$classes[] = 'no-dates';
		
	elseif ( 'no-hover' == $current_layout )
		$classes[] = 'no-hover';

	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'adventurebound_layout_classes', $classes, $current_layout );
	
	return array_merge( $existing_classes, $classes );}

function adventurebound_featured_images( $existing_classes ) {
	$options = adventurebound_get_theme_options();
	$current_layout = $options['featured_image'];

	if ( 'featured' == $current_layout )
		$classes[] = 'featured';

	elseif ( 'no-featured' == $current_layout )
		$classes[] = 'no-featured';

	elseif ( 'postonly' == $current_layout )
		$classes[] = 'postonly';
	
	elseif ( 'pageonly' == $current_layout )
		$classes[] = 'pageonly';

	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'adventurebound_featured_images', $classes, $current_layout );

	return array_merge( $existing_classes, $classes ); }
	
function adventurebound_hide_tags( $existing_classes ) {
	$options = adventurebound_get_theme_options();
	$current_layout = $options['hide_tag'];

	if ( 'tags' == $current_layout )
		$classes[] = 'tags';

	elseif ( 'no-tags' == $current_layout )
		$classes[] = 'no-tags';

	else
		$classes[] = $current_layout;

	$classes = apply_filters( 'adventurebound_hide_tags', $classes, $current_layout );

	return array_merge( $existing_classes, $classes ); }

function adventurebound_active_final() {
	$options = adventurebound_get_theme_options();
	if ( $options['active'] == 'active' ) {	
		add_filter( 'body_class', 'adventurebound_layout_classes' );
		add_filter( 'body_class', 'adventurebound_featured_images' );
		add_filter( 'body_class', 'adventurebound_hide_tags' );
		function adventurebound_print_link_color_style() {
		$options = adventurebound_get_theme_options();
		$link_color = $options['link_color'];
		$default_options = adventurebound_get_default_theme_options();
		if ( $default_options['link_color'] == $link_color )
			return; ?>
<style>a, .next a:hover, .widget a:hover, .widget td a, .hiding a:hover, .search-terms {color: <?php echo $link_color; ?>;}
.posttitle, #reply-title, .reading h2 {border-bottom: 3px solid <?php echo $link_color; ?>;}
.comment.bypostauthor, .comment.bypostauthor.odd, .bypostauthor .avatar {background: <?php echo $link_color; ?> url(<?php echo get_template_directory_uri(); ?>/images/50.png);}
.donthide .bigimage {background: <?php echo $link_color; ?> url(<?php echo get_template_directory_uri(); ?>/images/stressedbig.png);}
.donthide .tallimage {background: <?php echo $link_color; ?> url(<?php echo get_template_directory_uri(); ?>/images/stressedtall.png);}
.donthide .smallimage {background: <?php echo $link_color; ?> url(<?php echo get_template_directory_uri(); ?>/images/stressedsmall.png;)}</style><?php }
		add_action( 'wp_head', 'adventurebound_print_link_color_style' ); }
	if ( function_exists( 'register_nav_menu' ) ) register_nav_menu( 'bottom', 'Bottom' ); }

add_action( 'after_setup_theme', 'adventurebound_active_final' );

function new_excerpt_more($more) { return '....'; }
	add_filter('excerpt_more', 'new_excerpt_more');

function adventurebound_setup(){
	add_custom_background();
	if ( !isset( $content_width ) ) $content_width = 920;
	register_nav_menu( 'menu', 'Menu' );
	add_theme_support( 'automatic-feed-links' );
	define('HEADER_TEXTCOLOR', '');
	define('HEADER_IMAGE', '%s/images/logo.png');
	define('HEADER_IMAGE_WIDTH', 920);
	define('HEADER_IMAGE_HEIGHT', 100);
	define('NO_HEADER_TEXT', true );
	add_custom_image_header( 'adventurebound_header_style', 'adventurebound_admin_header_style', 'adventurebound_admin_header_image' );
	if ( ! function_exists( 'adventurebound_header_style' ) ) : function adventurebound_header_style() {}endif;
	if ( ! function_exists( 'adventurebound_admin_header_style' ) ) : function adventurebound_admin_header_style() {}endif;
	if ( ! function_exists( 'adventurebound_admin_header_image' ) ) : function adventurebound_admin_header_image() {?><img class="left title" title="<?php bloginfo('name'); ?>" src="<?php header_image(); ?>" alt="<?php bloginfo('description');?>" ><?php }endif;
	add_editor_style();
	add_theme_support( 'post-thumbnails', array( 'post', 'page' ) );
	add_image_size( 'page-thumbnail', 460, 259, true );
	add_image_size( 'big-thumbnail', 610, 355, true );
	add_image_size( 'tall-thumbnail', 300, 355, true );
	add_image_size( 'small-thumbnail', 300, 173, true );}
	
add_action( 'after_setup_theme', 'adventurebound_setup' );

/* Redirect to the theme options Page after theme is activated */
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" )
	wp_redirect( 'themes.php?page=theme_options' ); 

/* Add link to theme options in Admin bar. */ 
function adventurebound_admin_link() {
	global $wp_admin_bar;
	$wp_admin_bar->add_menu( array( 'id' => 'Adventure Bound Basic', 'title' => 'Adventure Bound Theme Options', 'href' => admin_url( 'themes.php?page=theme_options' ) )); }

	add_action( 'admin_bar_menu', 'adventurebound_admin_link', 113 );

/* Add Favicon */
function adventurebound_favicon() { ?>
<link rel="shortcut icon" href="<?php echo get_stylesheet_directory_uri(); ?>/images/favicon.ico" />
	<?php }
	
	add_action('wp_head', 'adventurebound_favicon');

register_sidebars(3, array(
	'name'=>'widget%d',
	'id' => 'widget',
	'description' => 'Widgets in this area will be shown below the the content of every page.',
	'before_widget' => '',
	'after_widget' => '',
	'before_title' => '<h2>',
	'after_title' => '</h2>',));
	
function is_sidebar_active($index) {
	global $wp_registered_sidebars;
	$widgetcolums = wp_get_sidebars_widgets();
	if ($widgetcolums[$index]) return true;
	return false; }

function adventure_enqueue_comment_reply() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) 
	wp_enqueue_script( 'comment-reply' ); }

add_action( 'wp_enqueue_scripts', 'adventure_enqueue_comment_reply' );

function print_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<div id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
	<div class="avatar"><?php echo get_avatar( $comment, 100 ); ?></div>
	<div class="commentinfo"><?php comment_author_link() ?> commented</div>
	<?php if ($comment->comment_approved == '0') : ?><em>Your comment is awaiting moderation.</em><br /><?php endif; ?>
	<?php comment_text() ?>
	<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
	<div class="right"><?php comment_date() ?> at <?php comment_time() ?> <?php edit_comment_link(__('(Edit)'),'  ','') ?></div>
	</div><?php }

?>